# -*- coding: utf-8 -*-

import datetime

holidays = [
    datetime.date(2020, 1, 1), datetime.date(2020, 1, 2), datetime.date(2020, 1, 3), datetime.date(2020, 1, 4),
    datetime.date(2020, 1, 5), datetime.date(2020, 1, 6), datetime.date(2020, 1, 7), datetime.date(2020, 1, 8),
    datetime.date(2020, 2, 24), datetime.date(2020, 3, 9), datetime.date(2020, 5, 1), datetime.date(2020, 5, 4),
    datetime.date(2020, 5, 5), datetime.date(2020, 5, 11), datetime.date(2020, 6, 12), datetime.date(2020, 11, 4)
]

short_days = [
    datetime.date(2020, 4, 30), datetime.date(2020, 5, 8), datetime.date(2020, 6, 11), datetime.date(2020, 11, 3),
    datetime.date(2020, 12, 31)
]

work_weekends = []



# -*- coding: utf-8 -*-

import datetime
from work_calendar_ru.data import holidays


class WCR:
    """Checking current day or time methods"""

    def __init__(self, start_hour, start_minutes, end_hour, end_minutes):
        self.start_hour = start_hour
        self.start_minutes = start_minutes
        self.end_hour = end_hour
        self.end_minutes = end_minutes
        self.current_day = datetime.date.today()
        self.current_time = datetime.datetime.now().time()

    def is_work_time(self):
        work_hours = (
            datetime.time(self.start_hour, self.start_minutes, 0),
            datetime.time(self.end_hour, self.end_minutes, 0)
        )

        if self.current_day not in holidays.holidays and self.current_day.weekday() not in (5, 6) \
                and work_hours[0] <= self.current_time <= work_hours[1]:
            return True
        else:
            return False

    def is_holiday(self):
        if self.current_day in holidays.holidays:
            return True
        else:
            return False

    def is_work_day(self):
        if (self.current_day not in holidays.holidays and self.current_day.weekday() not in (5, 6)) or \
                (self.current_day not in holidays.holidays and self.current_day in holidays.work_weekends):
            return True
        else:
            return False

    def is_short_work_day(self):
        if self.current_day in holidays.short_days:
            return True
        else:
            return False

    def is_work_weekend(self):
        if self.current_day in holidays.work_weekends:
            return True
        else:
            return False

    def is_weekend(self):
        if self.current_day.weekday() in (5, 6) and self.current_day not in holidays.work_weekends:
            return True
        else:
            return False



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='work_calendar_ru',
    version='1.1.2',
    packages=find_packages(),
    url='https://github.com/SLRover/work-calendar-ru',
    license='MIT',
    author='Ilya Sapunov',
    author_email='ilya.sapunov@gmail.com',
    description='Russian work calendar',
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
